<?php /* /momo/lib/lib_download.php, (c) 2008, Andreas Forstinger, www.mobilemoodle.org */
/// this script is based on the sample msgserverinterface.php by Matthias Meisenberger, elibera.com

/**
 * returns the full download URL for this client:
 * @param momoUrl is the URL to the mobile view of Moodle, eg: http://www.mobileclassroom.at/moodle18/momo/index.php
 * @param user if you want to generate a download URL for a client version, which is already preconfigured with this username
 * @param passplain if you want to generate a download URL for a client version, which is already preconfigured with this plain text password
 * @param tel if you want to generate a download URL for a client version, which is already preconfigured with this telefon number
 * @param passencrypted if you want to generate a download URL for a client version, which is already preconfigured with this encrypted password
 */
function generateMOMODownloadURL($momoUrl, $user=NULL,$passplain=NULL,$tel=NULL,$passencrypted=NULL)
{
	global $CFG;
	$ticketID=generateMOMODownloadTicketID($momoUrl,$user,$passplain,$tel,$passencrypted);
	return $CFG->momo_mle_device_distribution_http_ticket_download_url.$ticketID;
}

/**
 * returns only the ticket-ID for downloading this client:
 * @param momoUrl is the URL to the mobile view of Moodle, eg: http://www.mobileclassroom.at/moodle18/momo/index.php
 * @param user if you want to generate a download URL for a client version, which is already preconfigured with this username
 * @param passplain if you want to generate a download URL for a client version, which is already preconfigured with this plain text password
 * @param tel if you want to generate a download URL for a client version, which is already preconfigured with this telefon number
 * @param passencrypted if you want to generate a download URL for a client version, which is already preconfigured with this encrypted password
 */
function generateMOMODownloadTicketID($momoUrl, $user=NULL,$passplain=NULL,$tel=NULL,$passencrypted=NULL)
{
	global $CFG;
	$params = generateMOMODownloadTicketURLParams($momoUrl,$user,$passplain,$tel,$passencrypted);
	//print($CFG->momo_mle_device_distribution_server_host . ':' . $CFG->momo_mle_device_distribution_server_port);
	$fp = fsockopen($CFG->momo_mle_device_distribution_server_host, $CFG->momo_mle_device_distribution_server_port, $errno, $errstr, 30);
	if (!$fp) {
		//print($errno . $errstr);
		return 'error:connect';
	} else
	{
		$response = '';
		$out = 'GET '.$CFG->momo_mle_device_distribution_server_uri.$params." HTTP/1.0\r\n";
	    $out .= "Host: $CFG->momo_mle_device_distribution_server_host:$CFG->momo_mle_device_distribution_server_port\r\n";
	    $out .= "Connection: Close\r\n\r\n";
		fwrite($fp, $out);
		while (!feof($fp)) {
	        $response.= fgets($fp, 128);
	    }
		fclose($fp);
		$pos=stripos($response,"\r\n\r\n");
		if($pos!==false&&$pos>0)
			return trim(substr($response,$pos));
		return $response;
	}
}
/**
 * returns just the URL to retrieve the ticked-ID
 * @param momoUrl is the URL to the mobile view of Moodle, eg: http://www.mobileclassroom.at/moodle18/momo/index.php
 * @param user if you want to generate a download URL for a client version, which is already preconfigured with this username
 * @param passplain if you want to generate a download URL for a client version, which is already preconfigured with this plain text password
 * @param tel if you want to generate a download URL for a client version, which is already preconfigured with this telefon number
 * @param passencrypted if you want to generate a download URL for a client version, which is already preconfigured with this encrypted password
 */
function generateMOMODownloadTicketURLParams($momoUrl, $user=NULL,$passplain=NULL,$tel=NULL,$passencrypted=NULL)
{
	global $CFG;

	// constants
	$PREFIX='JAD-';
	$SERVERURLS=$PREFIX.'SERVERURLS';
	$SERVERGATEWAY=$PREFIX.'GATEWAY';
	$SERVERMSGSERVER=$PREFIX.'MSGSERVER';
	$SERVERUSERNAME=$PREFIX.'USER';
	$SERVERPASSPLAIN=$PREFIX.'PASS-CL';
	$SERVERPASSENC=$PREFIX.'PASS';
	$SERVERTEL=$PREFIX.'TEL';
	$SERVERHOSTID=$PREFIX.'MSGHOSTID';

	$params='app='.$CFG->momo_mle_msgserver_servername.'&'.$SERVERURLS.'='.urlencode($momoUrl).
	'&'.$SERVERHOSTID.'='.urlencode($CFG->momo_msg_hostid);
	if(empty($CFG->momo_public_msg_enabled))
	{// we use a custom messaging server
		$params=$params.'&'.$SERVERMSGSERVER.'='.urlencode('socket://'.$CFG->momo_msg_host.':'.$CFG->momo_msg_port);
	}
	if(empty($CFG->momo_public_gw_enabled))
	{// we use a custom gateway server
		$params=$params.'&'.$SERVERGATEWAY.'='.urlencode('socket://'.$CFG->momo_gw_host.':'.$CFG->momo_gw_port);
	}
	if($user!=NULL)
	{// we use a predfined username
		$params=$params.'&'.$SERVERUSERNAME.'='.urlencode($user);
	}
	if($passplain!=NULL)
	{// we use a predfined password, unencrypted
		$params=$params.'&'.$SERVERPASSPLAIN.'='.urlencode($passplain);
	}
	if($passencrypted!=NULL)
	{// we use a predfined password, encrypted
		$params=$params.'&'.$SERVERPASSENC.'='.urlencode($passencrypted);
	}
	if($tel!=NULL)
	{// we use a predfined telefon number
		$params=$params.'&'.$SERVERTEL.'='.urlencode($tel);
	}
	return $params;
}

?>