<?php /* /momo/lib/supported_modules.php, (c) 2006, Andreas Forstinger, www.mobilemoodle.org */

// this script is the main extension point for momo
// here the moodle modules are mapped to their related mobile implementations
// if you implement a new moodle module for mobile usage you have to add it here

/**
 * This function returns an array containing links to the supported activities in a specifig section (if given)
 * @param int course
 * @param int section id(!) of section or null
 * @param array or false on error
 */
function momo_get_activity_links($courseid, $sectionid = '') {
    // check if to use section
    if ($sectionid == '') {
        $sectionmode = false;
    } else {
        $sectionmode = true;
    }

    // check the given course
    if (!$course = get_record('course', 'id', $courseid)) {
        return false;
    }

    // define return structure
    $result = array ();

    // get activities in this course
    $activities = array ();

    // get activities in correct order (taken from get_array_of_activities
    if (!$rawmods = get_course_mods($courseid)) {}
    if ($sectionlist = get_records("course_sections", "course", $courseid, "section ASC")) {
        foreach ($sectionlist as $section) {
            if (!empty ($section->sequence)) {
                $sequence = explode(",", $section->sequence);
                foreach ($sequence as $seq) {
                    if (empty ($rawmods[$seq])) {
                        continue;
                    }
                    $activities[$seq]->cm = $rawmods[$seq]->id;
                    $activities[$seq]->mod = $rawmods[$seq]->modname;
                    $activities[$seq]->section = $section->section;
                    $activities[$seq]->name = urlencode(get_field($rawmods[$seq]->modname, "name", "id", $rawmods[$seq]->instance));
                    $activities[$seq]->visible = $rawmods[$seq]->visible;
                }
            }
        }
    }

    foreach ($activities as $activity) {
        if ($sectionmode) {
            if ($activity->section != $sectionid) {
                continue;
            }
        }
        // get link for activity
        $link = momo_get_activity_link($activity->mod, $activity->cm, false);
        if ($link != false) {
            $result[] = $link;
        }
    }
    return $result;
}

/**
 * This method is invoked internally to print a single link for a module
 * @param $modulename the name of the current module
 * @param $cmid coursemodule object containing helpful data
 * @return the link as string or false
 */
function momo_get_activity_link($modulename, $cmid, $ignorevisibility = false) {

	global $CFG;

    // get course module
    if (!$cm = get_record('course_modules', 'id', $cmid)) {
        return false;
    }

    if(!$ignorevisibility){
        if(empty($cm->visible)){
            return false;
        }
    }

    // switch modulename
    // this way this function can easily be extended

    switch ($modulename) {
        case 'choice' :
            // get choice object
            $choice = get_record('choice', 'id', $cm->instance);
            // we do not want links to choices not open
            if ((!empty ($choice->timeopen) && ($choice->timeopen > time())) || (!empty ($choice->timeclose) && ($choice->timeclose <= time()))) {
                $result = false;
            } else {
                $result = '<menu type="' . $CFG->momo_mle_server_link . '" u="choice/choice.php&amp;id=' . $choice->id . '" dt="l" di="' . momo_get_icon_path('mod_choice') . '" w="' . momo_truncate($choice->name) . '" />';

            }
            break;

        case 'forum' :
            // get forum object
            $forum = get_record('forum', 'id', $cm->instance);
            $result = '<menu t="' . $CFG->momo_mle_server_link . '" u="forum/forum.php&amp;id=' . $forum->id . '" dt="l" di="' . momo_get_icon_path('mod_forum') . '" w="' . momo_truncate($forum->name) . '" />';
            break;

        case 'label' :
            // get label object
            $label = get_record('label', 'id', $cm->instance);
            $result = '<menu t="' . $CFG->momo_mle_server_link . '" u="course/label.php&amp;id=' . $label->id . '" dt="l" di="' . momo_get_icon_path('crs_label') . '" w="' . get_string('modulename','label') . '" />';
            break;

        case 'mlo' :
            // get mlo object
            $mlo = get_record('mlo', 'id', $cm->instance);
            // show special link, that either opens that MLO if it was already downloaded, or shows a download page
            $result = '<menu t="s|' . $CFG->momo_mle_server_id . '|mlo/mlo.php&amp;id=" u="' . $mlo->id . '" dt="l" di="' . momo_get_icon_path('mod_mlo') . '" w="' . momo_truncate($mlo->name) . '" />';
            break;
        case 'resource' :
            // get resource object
            $resource = get_record('resource', 'id', $cm->instance);
            $result = '<menu t="' . $CFG->momo_mle_server_link . '" u="resource/resource.php&amp;id=' . $resource->id . '" dt="l" di="' . momo_get_icon_path('mod_resource') . '" w="'  . momo_truncate($resource->name) . '" />';
            break;

            // if requested module is not supported return false
        default :
            $result = false;
            break;
    }
    return $result;
}


/**
 * This function works like momo_get_activity_link and returns a link to the given course
 *
 */
function momo_get_course_link($courseid, $coursename = ''){
	global $CFG;
    if(empty($coursename))
        $coursename = get_field('course','fullname','id',"$courseid");
    return '<menu type="' . $CFG->momo_mle_server_link . '" u="course/course.php&amp;id=' . $courseid . '" dt="l" di="' . momo_get_icon_path('crs_course') . '" w="' . momo_truncate($coursename) .'" />';
}


?>